@@ -48,7 +48,7 @@
       remainingset <- remainingset[!is.na(remainingset)]
     }
 
-    if (nrow(ctable) == 1 || ctable$P[1] > alpha) { iterationexit <- TRUE }
+    if (nrow(ctable) == 1 || ctable$P[1] > alpha || is.na(ctable$P[1])) { iterationexit <- TRUE }
     if (!iterationexit && !retest) {
       if (all(ctable$P[seq(nrow(ctable))[-1]] >= alpha |
               is.na(ctable$P[seq(nrow(ctable))[-1]]))) { iterationexit <- TRUE }
